from pyramid.config import Configurator


def includeme(config: Configurator):
    """
    Function that gets included in server.py::main(); calls all route adding functions

    :param config: Pyramid server config object
    """
    default_routes(config)
    notification_routes(config)
    notification_sending_routes(config)


def default_routes(config: Configurator):
    """
    Uncategorized server routes

    :param config: Pyramid server config object
    """
    config.add_route("home", "/")


def notification_routes(config: Configurator):
    """
    Server routes for creating, updating, and removing Notification templates

    :param config: Pyramid server config object
    """
    config.add_route(
        name="view_notifications",
        pattern="/notify",
        request_method="GET"
    )
    config.add_route(
        name="create_notification",
        pattern="/notify/create",
        request_method="POST"
    )
    config.add_route(
        name="delete_notification",
        pattern="/notify/{template_name}/delete",
        request_method="DELETE"
    )


def notification_sending_routes(config: Configurator):
    """
    Server routes for sending Notifications

    :param config: Pyramid server config object
    """
    config.add_route(
        name="send_notification",
        pattern="/notify/{template_name}/send",
        request_method="POST"
    )
